@@ -1,32 +1,13 @@
-import os
-import collections
 from PIL import Image
-import copy
-import requests
-import time
-import sys
-from urllib import request
 from gmapsbounds import utils
 from gmapsbounds import constants
+from gmapsbounds import llpx
 
 MAX_BLUE_GREEN_DIFFERENCE = 20
 VALID = [[232, 151, 142], [237, 162, 155]]
 INVALID = [[215, 60, 48], [218, 97, 97], [179, 56, 44], [180, 56, 44]]
 # Highway signs (domestic), Hospitals, Highway signs (foreign), city names
 
-def write_coordinates(dir, nodes):
-    with open(os.path.join(dir, 'coordinates.txt'), 'w') as f:
-        for node_collection in nodes:
-            f.write('[\n')
-            for node in node_collection:
-                f.write('{}, {}\n'.format(node.lat, node.lng))
-            f.write(']\n')
-
-def load_image(filename):
-    im = Image.open(filename)
-    im.load()
-    return im.convert('RGB')
-
 def get_nodes(rgb_image):
     nodes = []
     width, height = rgb_image.size
@@ -140,57 +121,19 @@ def add_skipped_nodes(x, y, do_not_check):
     do_not_check.add((x+1, y+1))
     do_not_check.add((x, y+1))
 
-class Map:
-    def __init__(self, center, boundaries, pixwidth, pixheight):
-        self.center = center
-        self.north = boundaries[2]
-        self.east = boundaries[3]
-        self.south = boundaries[0]
-        self.west = boundaries[1]
-        self.pixwidth = pixwidth
-        self.pixheight = pixheight
-        self.nodes = []
-        
-    def attach_nodes(self, nodes):
-        self.nodes = nodes
-        for node_collection in nodes:
-            for node in node_collection:
-                node.map = self
-
-    @property
-    def width(self):
-        '''
-        Longitudinal width of the map
-        '''
-        return abs(self.east - self.west)
-
-    @property
-    def height(self):
-        return abs(self.north - self.south)
-
-
 class Node:
     def __init__(self, x, y):
         self.x = x
         self.y = y
-        self.map = None
+        self.location = None
         self.visited = False
 
-    @property
-    def lat(self):
-        return self.map.north - self.y/self.map.pixheight*self.map.height
-
-    @property
-    def lng(self):
-        return self.map.west + self.x/self.map.pixwidth*self.map.width
-
+    def get_lat_lng(self):
+        return llpx.pixels_to_lat_lng(self.location.offset[0] - self.location.pixcenter[0] + self.x,
+            self.location.offset[1] - self.location.pixcenter[1] + self.y, self.location.zoom)
 
     def __str__(self):
         return '<Node at {}, {}>'.format(self.x, self.y)
 
     def __repr__(self):
-        return self.__str__()
-
-
-if __name__ == '__main__':
-    main()
\ No newline at end of file
+        return self.__str__()
\ No newline at end of file
